@@ -9,7 +9,7 @@ module Main where
 import System.Environment
 import System.Exit
 import System.IO
-import Data.List (nub,takeWhile,dropWhile)
+import Data.List (nub)
 import Control.Monad
 
 --import Text.XML.HaXml.Wrappers   (fix2Args)
@@ -17,21 +17,21 @@ import Text.XML.HaXml            (version)
 import Text.XML.HaXml.Types      (DocTypeDecl(..))
 import Text.XML.HaXml.Namespaces (localName)
 import Text.XML.HaXml.Parse      (dtdParse)
-import Text.XML.HaXml.DtdToHaskell.TypeDef  (TypeDef,ppTypeDef,mangle)
+import Text.XML.HaXml.DtdToHaskell.TypeDef  (ppTypeDef,mangle)
 import Text.XML.HaXml.DtdToHaskell.Convert  (dtd2TypeDef)
 import Text.XML.HaXml.DtdToHaskell.Instance (mkInstance)
 import Text.PrettyPrint.HughesPJ (render,vcat)
 
--- sucked in from Text.XML.HaXml.Wrappers to avod dependency on T.X.H.Html
+-- sucked in from Text.XML.HaXml.Wrappers to avoid dependency on T.X.H.Html
 fix2Args :: IO (String,String)
 fix2Args = do
   args <- getArgs
   when ("--version" `elem` args) $ do
       putStrLn $ "part of HaXml-"++version
-      exitWith ExitSuccess
+      exitSuccess
   when ("--help" `elem` args) $ do
-      putStrLn $ "See http://haskell.org/HaXml"
-      exitWith ExitSuccess
+      putStrLn "See http://haskell.org/HaXml"
+      exitSuccess
   case length args of
     0 -> return ("-",     "-")
     1 -> return (args!!0, "-")
@@ -50,9 +50,10 @@ main =
     else openFile outf WriteMode ) >>= \o->
   let (DTD name _ markup) = (getDtd . dtdParse inf) content
       decls = (nub . dtd2TypeDef) markup
-      realname = if outf/="-" then mangle (trim outf)
-                 else if null (localName name) then mangle (trim inf)
-                 else mangle (localName name)
+      realname
+        | outf /= "-" = mangle (trim outf)
+        | null (localName name) = mangle (trim inf)
+        | otherwise = mangle (localName name)
   in
   do hPutStrLn o ("module "++realname
                   ++" where\n\nimport Text.XML.HaXml.XmlContent"
@@ -69,10 +70,9 @@ main =
 
 getDtd :: Maybe t -> t
 getDtd (Just dtd) = dtd
-getDtd (Nothing)  = error "No DTD in this document"
+getDtd Nothing    = error "No DTD in this document"
 
 trim :: [Char] -> [Char]
 trim name | '/' `elem` name  = (trim . tail . dropWhile (/='/')) name
           | '.' `elem` name  = takeWhile (/='.') name
           | otherwise        = name
-
